function random_walk_simulation(distribution,alpha)

if nargin == 0
    distribution = 'constant';
else
    distribution = lower(distribution);
end

Nparticles = 10000;
Nsteps = 10000;
mu = 5e-3;  % mean absolute step size

%% Step size distribution
switch distribution
    case 'constant'
        alpha = 2;
        Delta_pd = makedist('Uniform', 'lower', mu, 'upper', mu+eps(mu));  % var == 0
    case 'exponential'
        alpha = 2;
        Delta_pd = makedist('Exponential', 'mu', mu);  % var == mu^2
    case 'pareto'
        xm = (alpha-1)*mu / alpha;

        % MATLAB only supports "Generalised" Pareto, so there is some fiddling required here
        k = 1 / alpha;
        sigma = k * xm;
        theta = sigma / k;
        Delta_pd = makedist('GeneralizedPareto', 'k', k, 'sigma', sigma, 'theta', theta);  % var == inf
        
end


%% Random walk simulation
x = zeros(1,Nparticles);    % set all positions to zero initially

% Simulation
for n = 1:Nsteps
    DeltaDist = Delta_pd.random(1,Nparticles);  % step sizes
    CoinFlip = sign(rand(1,Nparticles) - 0.5);  % jumping left or right?
    x = x + CoinFlip .* DeltaDist;              % update each particle
end

%% Plot histogram of particles final positions
numBins = 101;
if isequal(distribution, 'pareto')
    L = quantile(abs(x), 0.95) * 2;
else
    L = range(abs(x));
end
figure
histogram(x, 'BinEdges', linspace(-L, L, numBins), 'Normalization','pdf');
xlim([-L, L])
legend('Random walk simulation')

%% Calculate the diffusion coefficient
% To compare random walk simulation to fractional Laplacian solution, we
% need to know what the diffusivity D is.
% The numerical solution is u(t_n) = exp(-A^(alpha/2)*D*t_n).
% We will take t_n = 1 for convenience.

% For fractional diffusion from the Pareto distribution we have:
if alpha < 2
    D = Nsteps * -alpha*cos(pi*alpha/2)*gamma(-alpha) * xm^alpha

% For standard diffusion we have:
else
    D = Nsteps * (mean(Delta_pd)^2 + var(Delta_pd)) / 2
end

%% Fractional Laplacian finite difference matrix
Nmesh = 2000;
h = 4*L/Nmesh;
X = linspace(-2*L, 2*L, Nmesh+1);
assert(norm(diff(X)-h, inf) < 1e-12); % check no bugs in mesh calculation!

% Delta function initial condition
u0 = zeros(Nmesh+1,1);  u0(Nmesh/2+1) = 1/h;

% Matrix
A = 1/h^2*full(gallery('tridiag', Nmesh+1));

%% Plot numerical solution to the fractional Laplacian
hold on
un = expm(-A^(min(alpha,2)/2)*D)*u0;
plot(X, un, 'LineWidth', 1.5, 'DisplayName', 'PDE solution')